.. _primitives_pipelines:

Primitives and Pipelines
========================

**Orion** uses the basic building blocks of primitives to compose pipelines, we provide some 
resources to read more about available primitives and pipelines, and how you can compose 
and formulate your own

.. toctree::
    :maxdepth: 3

    primitives
    pipelines